lilypondfiletools.BookpartBlock
===============================

.. inheritance-diagram:: abjad.tools.lilypondfiletools.BookpartBlock.BookpartBlock.BookpartBlock
   :private-bases:

.. autoclass:: abjad.tools.lilypondfiletools.BookpartBlock.BookpartBlock.BookpartBlock

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.lilypondfiletools.BookpartBlock.BookpartBlock.BookpartBlock.lilypond_format

    Inherited from :py:class:`lilypondfiletools.NonattributedBlock <abjad.tools.lilypondfiletools.NonattributedBlock.NonattributedBlock.NonattributedBlock>`

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.lilypondfiletools.BookpartBlock.BookpartBlock.BookpartBlock.is_formatted_when_empty

    Inherited from :py:class:`lilypondfiletools.NonattributedBlock <abjad.tools.lilypondfiletools.NonattributedBlock.NonattributedBlock.NonattributedBlock>`

Methods
-------

.. automethod:: abjad.tools.lilypondfiletools.BookpartBlock.BookpartBlock.BookpartBlock.append

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.BookpartBlock.BookpartBlock.BookpartBlock.count

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.BookpartBlock.BookpartBlock.BookpartBlock.extend

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.BookpartBlock.BookpartBlock.BookpartBlock.index

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.BookpartBlock.BookpartBlock.BookpartBlock.insert

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.BookpartBlock.BookpartBlock.BookpartBlock.pop

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.BookpartBlock.BookpartBlock.BookpartBlock.remove

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.BookpartBlock.BookpartBlock.BookpartBlock.reverse

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.BookpartBlock.BookpartBlock.BookpartBlock.sort

    Inherited from :py:class:`__builtin__.list`

Special Methods
---------------

.. automethod:: abjad.tools.lilypondfiletools.BookpartBlock.BookpartBlock.BookpartBlock.__add__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.BookpartBlock.BookpartBlock.BookpartBlock.__contains__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.BookpartBlock.BookpartBlock.BookpartBlock.__delitem__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.BookpartBlock.BookpartBlock.BookpartBlock.__delslice__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.BookpartBlock.BookpartBlock.BookpartBlock.__eq__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.BookpartBlock.BookpartBlock.BookpartBlock.__ge__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.BookpartBlock.BookpartBlock.BookpartBlock.__getitem__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.BookpartBlock.BookpartBlock.BookpartBlock.__getslice__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.BookpartBlock.BookpartBlock.BookpartBlock.__gt__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.BookpartBlock.BookpartBlock.BookpartBlock.__iadd__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.BookpartBlock.BookpartBlock.BookpartBlock.__imul__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.BookpartBlock.BookpartBlock.BookpartBlock.__iter__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.BookpartBlock.BookpartBlock.BookpartBlock.__le__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.BookpartBlock.BookpartBlock.BookpartBlock.__len__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.BookpartBlock.BookpartBlock.BookpartBlock.__lt__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.BookpartBlock.BookpartBlock.BookpartBlock.__mul__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.BookpartBlock.BookpartBlock.BookpartBlock.__ne__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.BookpartBlock.BookpartBlock.BookpartBlock.__repr__

    Inherited from :py:class:`lilypondfiletools.NonattributedBlock <abjad.tools.lilypondfiletools.NonattributedBlock.NonattributedBlock.NonattributedBlock>`

.. automethod:: abjad.tools.lilypondfiletools.BookpartBlock.BookpartBlock.BookpartBlock.__reversed__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.BookpartBlock.BookpartBlock.BookpartBlock.__rmul__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.BookpartBlock.BookpartBlock.BookpartBlock.__setitem__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.BookpartBlock.BookpartBlock.BookpartBlock.__setslice__

    Inherited from :py:class:`__builtin__.list`
